﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

namespace HeuristicLab.Problems.Instances.QAPGenerator {
  public sealed class TaiaQAPInstanceGeneratorDescriptor : QAPInstanceGeneratorDescriptor {

    public override string Name {
      get { return "Tai-a Instances"; }
    }

    public override string Description {
      get { return "Generates uniformly distributed random symmetric QAP instances."; }
    }

    public TaiaQAPInstanceGeneratorDescriptor() {
      // default ctor should result in a valid configuration
      N = 6;
      Seed = 123456789; // Taillard's default seed
    }

    public override QAPData GetInstance() {
      double[,] A, B;
      TaillardQAPInstanceGenerator.GenerateTaia(N, out A, out B, new Bratley(Seed));
      return new QAPData {
        Name = "tai" + N.ToString("00") + "a",
        Description = "Instance generated with TaillardQAPInstanceGenerator.GenerateTaia",
        Dimension = N,
        Weights = B,
        Distances = A
      };
    }
  }
}
